#!/bin/bash
# Filename: build-htop.sh
# Automates the packaging process of the software "htop" for
# use with Zenwalk Linux.  
# Copyright (C) 2009 Michael Verret michael.verret@gmail.com
# Software source: http://htop.sourceforge.net/
# Software dependencies: "ncurses"

WorkArea=$(pwd)
SoftwareName='htop'
SoftwareVersion='0.8.1'
CompressionAlgorithm='tar.gz'
Arch='i686'
Build='62.1'
Package="$SoftwareName-$SoftwareVersion-$Arch-$Build"
InstallDir="$WorkArea/$Package"
DocDir="$InstallDir/usr/doc/$SoftwareName-$SoftwareVersion"
SrcDir="$InstallDir/usr/src/$SoftwareName-$SoftwareVersion"
Documentation="AUTHORS COPYING ChangeLog INSTALL NEWS README TODO"

# Files from previous builds are considered cruft.
Cruft="$SoftwareName-$SoftwareVersion $Package $Package.*"
for Each in ${Cruft} ; do
	if [ -e $Each ] ; then
		rm -rf $Each
	fi
done

tar -xvzf $SoftwareName-$SoftwareVersion.$CompressionAlgorithm

cd $SoftwareName-$SoftwareVersion
chown -R root:root .
find . \
	\( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
	-exec chmod 755 {} \; -o \
	\( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
	-exec chmod 644 {} \;

./configure CFLAGS="-O2 -march=$Arch -pipe" CXXFLAGS="-O2 -march=$Arch -pipe" \
	--prefix=/usr --mandir=/usr/man --disable-static --enable-unicode \
	--enable-taskstats --silent

make --silent || exit 1
make install --silent DESTDIR=$InstallDir || exit 1

cd $InstallDir
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
gzip -9 usr/man/*/*

mkdir -p $InstallDir/install
cat <<EOF0 > $InstallDir/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
htop: htop (Interactive text-mode process viewer for Linux.)
htop:
htop: htop is an interactive text-mode process viewer for Linux. It aims
htop: to be a better 'top'. htop is Linux specific since it is based on
htop: the Linux /proc filesystem. In htop you can scroll the list
htop: vertically and horizontally to see all processes and full command
htop: lines, can kill a process without typing the process number,
htop: renice a process without typing the process number or the priority
htop: value and you can kill multiple processes at once.
htop:
htop:
EOF0

mkdir -p $DocDir
cd $WorkArea/$SoftwareName-$SoftwareVersion
	cp $Documentation $DocDir
	cat $WorkArea/$SoftwareName-$SoftwareVersion/plpa-1.1/LICENSE > \
		$DocDir/LICENSE_plpa
	cat $WorkArea/$SoftwareName-$SoftwareVersion/plpa-1.1/README > \
		$DocDir/README_plpa
	cat $WorkArea/$SoftwareName-$SoftwareVersion/plpa-1.1/VERSION > \
		$DocDir/VERSION_plpa
	cat $WorkArea/$SoftwareName-$SoftwareVersion/plpa-1.1/AUTHORS > \
		$DocDir/AUTHORS_plpa

cd $DocDir ; find . -name "*" -size 0c -exec rm {} \;

# Install the icons (using the software "imagemagick"):
cd $InstallDir
	mkdir -p usr/share/icons/hicolor/{16x16,32x32,48x48}/apps
	convert usr/share/pixmaps/htop.png -resize 16x16 \
		$InstallDir/usr/share/icons/hicolor/16x16/apps/htop.png
	convert usr/share/pixmaps/htop.png -resize 32x32 \
		$InstallDir/usr/share/icons/hicolor/32x32/apps/htop.png
	convert usr/share/pixmaps/htop.png -resize 48x48 \
		$InstallDir/usr/share/icons/hicolor/48x48/apps/htops.png

# Delete empty directories:
rmdir $InstallDir/usr/include
rmdir $InstallDir/usr/lib

# Correct the desktop entry:
rm $InstallDir/usr/share/applications/htop.desktop
cat <<EOF1 > $InstallDir/usr/share/applications/htop.desktop
[Desktop Entry]
Encoding=UTF-8
Version=$SoftwareVersion
Name=Htop
Type=Application
Comment=Show System Processes
Terminal=true
Exec=htop
Path=
Icon=htop
Categories=ConsoleOnly;System;Application;
GenericName=Process Viewer
EOF1

mkdir -p $SrcDir
cd $WorkArea ; cp build-$SoftwareName.sh $SrcDir

cd $InstallDir ; makepkg -l y -c n $InstallDir.tlz
	
cd $WorkArea
	depfinder -f $Package.tlz
	md5sum $Package.tlz > $Package.md5
	rm -rf $SoftwareName-$SoftwareVersion $InstallDir

# CHANGELOG:
# ~ Sun Apr 19 2009	Michael Verret "axxium" michael.verret@gmail.com
# ~ Updated: htop 0.8.1

# ~ Sat Aug 09 2008 Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Updated: htop 0.8

# ~ Mon Dec 11 2008 Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Initial build: htop 0.7
